; NAME:                images_6_idl
;
; DESCRIPTION:       Reads and display a JPEG file
;
; EXECUTION COMMAND:
;                      IDL> .compile images_6_idl
;                      IDL> images_6_idl
;
; INPUTS:             JPEG file soho_image.jpeg
;
; OUTPUTS:             PDF file: plot.pdf
;
; NOTES:               change the input data. 
;                              change the output PDF name.
;
; AUTHOR:              Leonardo UBEDA
;                      Space Telescope Science Institute, USA 
; 
; REVISION HISTORY:
;                      Written by Leonardo UBEDA, Jun 2013. 
;
;

 

; ------------------------ idl code begins here
pro images_6_idl

!p.charthick = 3.0


; define page size (in cm)
page_height = 27.94
page_width = 21.59

 
 
;use postscript output 
set_plot, 'ps'

; name the output file 
psname = 'plot.ps'

; open the postscript file
device, filename = psname, $
xsize = page_width, $
ysize = page_height, $
xoffset = 0, $
yoffset = 0, $
scale_factor = 1.0, $
/portrait 

; define plot position and size (in cm)
plot_left = 3.
plot_bottom = 2
xsize = 15. 
ysize = 15. 
   
; read jpeg file    
read_jpeg,  'soho_image.jpg', image, true = 3  

; obtain image size
source_dim = size(image, /dim)

; display jpeg
cgimage, image, $
position = [plot_left / page_width, plot_bottom / page_height, (plot_left + xsize) / page_width, (plot_bottom + ysize) / page_height] 

; define coordinate system as reference 
cgplot, [0], [0],  $
color = cgcolor(black), $ 
xtickformat = "(a1)", $
ytickformat = "(a1)", $   
thick= 0, $
/nodata, $
/noerase, $
xrange= [0., source_dim[0]], $
yrange= [0., source_dim[1]], $
xstyle = 5, $
ystyle = 5, $
position = [plot_left / page_width, plot_bottom / page_height, (plot_left + xsize) / page_width, (plot_bottom + ysize) / page_height] 
 
; mark a region with a green rectangle
tvbox, 300, 850, 850, thick = 4, /data, color = cgcolor('green')

; extract said region from the original image
subimage = image[700:1000,700:1000,*]

; plot the sub region on the same page

; define plot position and size (in cm)
plot_left = 3.
plot_bottom = 18
xsize = 7. 
ysize = 7. 


cgimage, subimage, $
/noerase, $
position = [plot_left / page_width, plot_bottom / page_height, (plot_left + xsize) / page_width, (plot_bottom + ysize) / page_height] 
 
 
; obtain sub image size 
source_dim = size(subimage, /dim)

; define coordinate system as reference
cgplot, [0], [0], $
xtickformat = "(a1)", $
ytickformat = "(a1)", $   
thick = 5, $
/nodata,  $
/noerase, $
xrange= [0., source_dim[0]], $
yrange= [0., source_dim[1]], $
xstyle = 5, $
ystyle = 5, $
position = [plot_left / page_width, plot_bottom / page_height, (plot_left + xsize) / page_width, (plot_bottom + ysize) / page_height] 

; frame the sub image with a green rectangle
tvbox, 301, 151, 151, thick = 4, /data, color = cgcolor('green')
 
; close postscript file
device,/close

; create a PDF file
cgps2pdf, psname, /delete_ps

end
; ------------------------ idl code ends here
